==> corpjs-express-0.1.1.tgz: package/test_src/index.spec.ts <==
import 'mocha'
import * as assert from 'assert'
import System from 'corpjs-system'
import Endpoints from 'corpjs-endpoints'
import request = require('request-promise-native')
import { App, Server } from '../src'

process.on('unhandledRejection', err => console.error(err))

describe('corpjs-express', () => {

  let system

  beforeEach(async () => {
    if (system) await system.stop()
  })

  it('should start', async () => {
    system = createSystem(3000)
    const {app, server} = await system.start()
    assert.ok(app)
    assert.ok(server)
  })

  it('should access on a simple route', async () => {
    system = createSystem(3000)
    await system.start()
    const response = await request('http://localhost:3000')
    assert.strictEqual(response, 'OK')
  })

  it('should throw exception caused by port refusing', done => {
    system = createSystem(3000)
      .add('server2', Server()).dependsOn('app', { component: 'config', source: 'server', as: 'config' })
      .on('componentRunFailed', (componentName, err) => {
        try {
          assert.ok(componentName, 'server2')
          assert.ok(/EADDRINUSE/.test(err.message))
          done()
        } catch (e) { done(e) }
      })
    system.start()
  })

})

function createSystem(port: number): System {
  return new System({ exitOnError: false })
    .add('config', Config(port))
    .add('app', App())
    .add('router', Router()).dependsOn('app')
    .add('server', Server()).dependsOn('app', { component: 'config', source: 'server', as: 'config' })
}

function Config(port: number) {
  return {
    async start() {
      return { server: { port } }
    }
  }
}

function Router() {
  return {
    async start({app}) {
      app.get('/', (req, res) => {
        res.status(200).send('OK')
      })
    }
  }
}

==> corpjs-express-0.1.3.tgz: package/test_src/index.spec.ts <==
import 'mocha'
import * as assert from 'assert'
import System from 'corpjs-system'
import request = require('request-promise-native')
import { App, Server } from '../src'

process.on('unhandledRejection', err => console.error(err))

describe('corpjs-express', () => {

  let system

  beforeEach(async () => {
    if (system) await system.stop()
  })

  it('should start', async () => {
    system = createSystem(3000)
    const {app, server} = await system.start()
    assert.ok(app)
    assert.ok(server)
  })

  it('should access on a simple route', async () => {
    system = createSystem(3000)
    await system.start()
    const response = await request('http://localhost:3000')
    assert.strictEqual(response, 'OK')
  })

  it('should throw exception caused by port refusing', done => {
    system = createSystem(3000)
      .add('server2', Server()).dependsOn('app', { component: 'config', source: 'server', as: 'config' })
      .on('componentRunFailed', (componentName, err) => {
        try {
          assert.ok(componentName, 'server2')
          assert.ok(/EADDRINUSE/.test(err.message))
          done()
        } catch (e) { done(e) }
      })
    system.start()
  })

})

function createSystem(port: number, hostname?: string): System {
  return new System({ exitOnError: false })
    .add('config', Config(port, hostname))
    .add('app', App())
    .add('router', Router()).dependsOn('app')
    .add('server', Server()).dependsOn('app', { component: 'config', source: 'server', as: 'config' })
}

function Config(port: number, hostname?: string) {
  return {
    async start() {
      return { server: { port, hostname } }
    }
  }
}

function Router() {
  return {
    async start({app}) {
      app.get('/', (req, res) => {
        res.status(200).send('OK')
      })
    }
  }
}
